## Dataset Attribution

This dataset was created by combining the MedQA and DiversityMedQA datasets.
The _US_ portion of the MedQA dataset was downloaded from [github.com](https://github.com/jind11/MedQA),
its original MIT license is included in `LICENSE_MedQA`. The DiversityMedQa
dataset was downloaded from [huggingface.com](https://huggingface.co/datasets/Rajat1212/DiversityMedQA),
its original CC0 1.0 Universal license is included in `LICENSE_DivesityMedQA`.

The male and female sentences in our dataset (`diversity_med_qa_extracted.csv`)
are extracted from `DiversityMedQA` dataset, while the options are extracted
from the `MedQA` dataset.
